package consume

import (
	"applet/app/cfg"
	"applet/app/db"
	db2 "applet/app/db/gim"
	model2 "applet/app/db/gim/model"
	"applet/app/db/model"
	utils2 "applet/app/utils"
	"applet/app/utils/logx"
	utils "applet/app/utils/rpc"
	"applet/consume/md"
	"applet/pkg/pb"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_mq.git/rabbit"
	"encoding/json"
	"errors"
	"fmt"
	"github.com/streadway/amqp"
	"strconv"
	"time"
)

func DouShenUserRegisterConsumeForMyFans(queue md.MqQueue) {
	fmt.Println(">>>>>>>>>>>>DouShenUserRegisterConsumeForMyFans>>>>>>>>>>>>")
	ch, err := rabbit.Cfg.Pool.GetChannel()
	if err != nil {
		logx.Error(err)
		return
	}
	defer ch.Release()

	//1、将自己绑定到交换机上
	ch.Bind(queue.Name, queue.ExchangeName, queue.RoutKey)
	//2、取出数据进行消费
	ch.Qos(1)
	delivery := ch.Consume(queue.Name, false)

	var res amqp.Delivery
	var ok bool
	for {
		res, ok = <-delivery
		if ok == true {
			fmt.Println(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>")
			err = handleDouShenUserRegisterConsumeForMyFans(res.Body)
			if err != nil {
				fmt.Println("!!!!!!!err!!!!!!!", err)
				_ = res.Reject(false)

				utils2.FilePutContents("douShenUserRegisterConsumeForMyFans_err", "[err]:"+err.Error())
				if err.Error() == "用户暂未注册im系统" {
					//TODO::重新推回队列末尾，避免造成队列堵塞
					var msg *md.DouShenUserRegisterMessageStructForMyFans
					json.Unmarshal(res.Body, &msg)
					ch.Publish(queue.ExchangeName, msg, queue.RoutKey)
				}
			} else {
				_ = res.Ack(true)
			}
		} else {
			panic(errors.New("error getting message"))
		}
	}
	fmt.Println("get msg done")
}

func handleDouShenUserRegisterConsumeForMyFans(msgData []byte) error {
	time.Sleep(time.Duration(1) * time.Second)
	//1、解析mq中queue的数据结构体
	var msg *md.DouShenUserRegisterMessageStructForMyFans
	err := json.Unmarshal(msgData, &msg)
	if err != nil {
		return err
	}
	//2、查找用户对应im系统中的数据
	gimUser, err := db2.UserGetOneByParams(db.ImDb, msg.MasterId, map[string]interface{}{
		"key":   "phone_number",
		"value": msg.Phone,
	})
	if err != nil {
		return err
	}
	if gimUser == nil {
		user, err := db.UserFindByMobile(db.DBs[msg.MasterId], strconv.FormatInt(msg.Phone, 10))
		if err != nil {
			return err
		}
		userProfile, err := db.UserProfileFindByID(db.DBs[msg.MasterId], user.Uid)
		if err != nil {
			return err
		}

		gimUserId, err := db2.UserInsert(db.ImDb, &model2.User{
			PhoneNumber:        strconv.FormatInt(msg.Phone, 10),
			Nickname:           user.Nickname,
			AvatarUrl:          userProfile.AvatarUrl,
			Sex:                userProfile.Gender,
			CreateTime:         time.Now().Format("2006-01-02 15:04:05"),
			UpdateTime:         time.Now().Format("2006-01-02 15:04:05"),
			MasterId:           utils2.StrToInt64(msg.MasterId),
			IsAutoAddedFriends: 0,
		})
		if err != nil {
			return err
		}
		gimUser, err = db2.UserGetOneByParams(db.ImDb, msg.MasterId, map[string]interface{}{
			"key":   "id",
			"value": gimUserId,
		})
		if gimUser == nil {
			return errors.New("用户暂未注册im系统")
		}
	}

	groupName := "我的粉丝【1】群"
	//3、创建群
	resp, err := utils.GetLogicExtClient(cfg.ImLogicRpc.URL, cfg.ImLogicRpc.PORT).CreateGroup(utils.GetCtx("", utils2.Int64ToStr(gimUser.Id), "", msg.MasterId), &pb.CreateGroupReq{
		Name:      groupName,
		AvatarUrl: "",
		//Introduction: gimUser.Nickname + "的粉丝群",
		Introduction: "",
		Extra:        "",
		MemberIds:    nil,
	})
	if err != nil {
		return err
	}
	//插入 dou_shen_im_group 记录
	now := time.Now()
	_, err = db.DouShenImGroupInsert(db.Db, &model.DouShenImGroup{
		Kind:       3,
		Uid:        int(msg.Uid),
		GroupId:    int(resp.GroupId),
		IsFull:     0,
		Name:       groupName,
		CreateTime: now,
		UpdateTime: now,
	})
	if err != nil {
		return err
	}

	return nil
}
