package md

type MqQueue struct {
	ExchangeName   string `json:"exchangeName"`     //交换机名字
	Name           string `json:"name"`             //队列名字
	Type           string `json:"type"`             //队列类型
	IsPersistent   bool   `json:"is_persistent"`    //队列是否持久化
	RoutKey        string `json:"rout_key"`         //路由
	BindKey        string `json:"bind_key"`         //绑定的路由
	ConsumeFunName string `json:"consume_fun_name"` //消费方法
}

var RabbitMqQueueKeyList = []*MqQueue{
	{
		ExchangeName:   "",
		Name:           "cloud_issuance_async_mlogin",
		Type:           SimpleQueueType,
		IsPersistent:   false,
		RoutKey:        "",
		BindKey:        "",
		ConsumeFunName: "CloudIssuanceAsyncMLoginConsume",
	},
	{
		ExchangeName:   "canal.topic",
		Name:           "canal_order",
		Type:           TopicQueueType,
		IsPersistent:   false,
		RoutKey:        "canal_mall_order",
		BindKey:        "",
		ConsumeFunName: "CanalOrderConsume",
	},
	{
		ExchangeName:   "canal.topic",
		Name:           "canal_guide_order",
		Type:           TopicQueueType,
		IsPersistent:   false,
		RoutKey:        "canal_order_list",
		BindKey:        "",
		ConsumeFunName: "CanalGuideOrderConsume",
	},
	{
		ExchangeName:   "zhios.app.user.visit.ip.address.exchange",
		Name:           "zhios_user_visit_ip_address_queue",
		Type:           FanOutQueueType,
		IsPersistent:   false,
		RoutKey:        "queue_one",
		BindKey:        "",
		ConsumeFunName: "ZhiOsUserVisitIpAddressConsume",
	},
	{
		ExchangeName:   "zhios.order.fast.return.exchange",
		Name:           "zhios_fast_return_order_pay",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "order_pay",
		BindKey:        "",
		ConsumeFunName: "ZhiosFastReturnOrderPay",
	},
	{
		ExchangeName:   "zhios.order.fast.return.exchange",
		Name:           "zhios_fast_return_order_success",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "order_success",
		BindKey:        "",
		ConsumeFunName: "ZhiosFastReturnOrderSuccess",
	},
	{
		ExchangeName:   "zhios.order.fast.return.exchange",
		Name:           "zhios_fast_return_order_refund",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "order_refund",
		BindKey:        "",
		ConsumeFunName: "ZhiosFastReturnOrderRefund",
	},

	{
		ExchangeName:   "zhios.doushen.user.register.exchange",
		Name:           "zhios_doushen_user_register_my_fans",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "my_fans",
		BindKey:        "my_fans",
		ConsumeFunName: "DouShenUserRegisterConsumeForMyFans",
	},
	{
		ExchangeName:   "zhios.doushen.user.register.exchange",
		Name:           "zhios_doushen_user_register_operation_center",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "operation_center",
		BindKey:        "operation_center",
		ConsumeFunName: "DouShenUserRegisterConsumeForOperationCenter",
	},
	{
		ExchangeName:   "zhios.doushen.user.register.exchange",
		Name:           "zhios_doushen_user_register_my_recommender",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "my_recommender",
		BindKey:        "my_recommender",
		ConsumeFunName: "DouShenUserRegisterConsumeForMyRecommender",
	},
	{
		ExchangeName:   "zhios.doushen.user.register.exchange",
		Name:           "zhios_doushen_user_register_official",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "official",
		BindKey:        "official",
		ConsumeFunName: "DouShenUserRegisterConsumeForOfficial",
	},
	{
		ExchangeName:   "zhios.doushen.user.register.exchange",
		Name:           "zhios_doushen_user_register_user_comm_up_lv",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "user_register_comm_up_lv",
		BindKey:        "user_register_comm_up_lv",
		ConsumeFunName: "DouShenUserRegisterConsumeForUserRegisterUpLv",
	},
	{
		ExchangeName:   "canal.topic",
		Name:           "canal_mall_ord_for_you_mi_shang",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "canal_mall_order",
		BindKey:        "",
		ConsumeFunName: "CanalMallOrdForYouMiShang",
	},
	{
		ExchangeName:   "zhios.youmishang.exchange",
		Name:           "zhios_youmishang_exchange_store",
		Type:           DirectQueueType,
		IsPersistent:   false,
		RoutKey:        "store",
		BindKey:        "store",
		ConsumeFunName: "YoumishangExchangeStore",
	},
}

const (
	CanalOrderConsumeFunName                             = "CanalOrderConsume"
	CanalGuideOrderConsumeFunName                        = "CanalGuideOrderConsume"
	ZhiOsUserVisitIpAddressConsumeFunName                = "ZhiOsUserVisitIpAddressConsume"
	DouShenUserRegisterConsumeForOfficialFunName         = "DouShenUserRegisterConsumeForOfficial"
	DouShenUserRegisterConsumeForOperationCenterFunName  = "DouShenUserRegisterConsumeForOperationCenter"
	DouShenUserRegisterConsumeForMyRecommenderFunName    = "DouShenUserRegisterConsumeForMyRecommender"
	DouShenUserRegisterConsumeForMyFansFunName           = "DouShenUserRegisterConsumeForMyFans"
	DouShenUserRegisterConsumeForUserRegisterUpLvFunName = "DouShenUserRegisterConsumeForUserRegisterUpLv"
	ZhiosFastReturnOrderPayFunName                       = "ZhiosFastReturnOrderPay"
	ZhiosFastReturnOrderSuccessFunName                   = "ZhiosFastReturnOrderSuccess"
	ZhiosFastReturnOrderRefundFunName                    = "ZhiosFastReturnOrderRefund"
	CanalMallOrdForYouMiShangFunName                     = "CanalMallOrdForYouMiShang"
	YoumishangExchangeStoreFunName                       = "YoumishangExchangeStore"
	CloudIssuanceAsyncMLoginFunName                      = "CloudIssuanceAsyncMLoginConsume"
)
